## Baram

Cloud Framework for AWS Framework.

Baram means "wind" in Korean which makes cloud move conveniently.  

## For Framework Developer

You can build and install the package as below.

```commandline

$ ./build.sh
```